<?php

/**
 * mod_stabs
 *
 * @version 1.0
 * @author Creative Pulse
 * @copyright Creative Pulse 2009
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link http://www.creativepulse.eu
 */

defined('_JEXEC') or die('Restricted access');

class ModStabs {

	function instance_id($new = false) {
		static $num = 0;

		if ($new)
			$num++;
		else
			return $num;
	}

	function json_esc($input, $esc_lt_gt = true) {
		$result = '';
		$input = (string) $input;
		$conv = array( "'" => "'", '"' => '"', '&' => '&', '\\' => '\\', "\n" => 'n', "\r" => 'r', "\t" => 't', "\b" => 'b', "\f" => 'f' );

		if ($esc_lt_gt)
			$conv = array_merge($conv, array( '<' => 'u003C', '>' => 'u003E' ));

		for ($i = 0, $len = strlen($input); $i < $len; $i++)
			$result .= isset($conv[$input{$i}]) ? '\\' . $conv[$input{$i}] : $input{$i};

		return $result;
	}

	function get($key) {
		return isset($this->vars[$key]) ? $this->vars[$key] : trim($this->params->get($key, ''));
	}

	function fmt_str($key, $value) {
		return $value == '' ? '' : '	' . $key . ': "' . $this->json_esc($value) . '",' . "\n";
	}

	function fmt_int($key, $value) {
		return $value == 0 ? '' : '	' . $key . ': ' . $value . ',' . "\n";
	}

	function get_str($key, $default = null) {
		$value = $this->get($key);
		if ($value == '' && $default !== null)
			$value = $default;

		return $value == '' ? '' : '	' . $key . ': "' . $this->json_esc($value) . '",' . "\n";
	}

	function get_int($key, $default = null) {
		$value = $this->get($key);
		if ($value == '' && $default !== null)
			$value = $default;

		return $value == '' ? '' : '	' . $key . ': ' . intval($value) . ',' . "\n";
	}

	function get_bool($key, $default = null) {
		$value = $this->get($key);
		if ($value == '' && $default !== null)
			$value = $default;

		return $value == '' ? '' : '	' . $key . ': ' . ($value ? 'true' : 'false') . ',' . "\n";
	}

	function prepare(&$params) {
		$this->params = $params;

		$this->vars = array();
		$lines = explode("\n", str_replace("\r", '', $this->params->get('vars')));
		foreach ($lines as $line) {
			$e = explode(':', $line, 2);
			$k = strtolower(trim(@$e[0]));
			if ($k != '')
				$this->vars[$k] = trim(@$e[1]);
		}

		$document =& JFactory::getDocument();

		$css_file = $this->get('css_file');
		if ($css_file != '')
			$document->addStyleSheet($css_file);

		$this->instance_id(true);

		if ($this->instance_id() == 1) {
			$document->addScript('modules/mod_stabs/SlidingTabs.js');

			$document->addScriptDeclaration('
function mod_stabs_init() {
	for (var i = 0, len = document["mod_stabs_conf"].length; i < len; i++) {
		var params = document["mod_stabs_conf"][i];
		document[params.iname] = new SlidingTabs(params);
	}
}

if (window.addEventListener)
	window.addEventListener("load", mod_stabs_init, false);
else if (window.attachEvent)
	window.attachEvent("onload", mod_stabs_init);

document["mod_stabs_conf"] = new Array();

');
		}

		$this->iname = trim($this->get('instance_name'));
		if ($this->iname == '')
			$this->iname = 'stabs' . $this->instance_id();

		$this->tags_container_id = trim($this->get('tags_container_id'));
		if ($this->tags_container_id == '')
			$this->tags_container_id = $this->iname . '_tags_container';

		$this->tags_tr_id = trim($this->get('tags_tr_id'));
		if ($this->tags_tr_id == '')
			$this->tags_tr_id = $this->iname . '_tags';

		$this->data_container_id = trim($this->get('data_container_id'));
		if ($this->data_container_id == '')
			$this->data_container_id = $this->iname . '_data_container';

		$this->data_tr_id = trim($this->get('data_tr_id'));
		if ($this->data_tr_id == '')
			$this->data_tr_id = $this->iname . '_data';

		$this->tags_align = trim($this->get('tags_align'));
		$this->tags_width = trim($this->get('tags_width'));

		$images = '';
		foreach ($this->vars as $k => $v)
			if (preg_match('/^image\d+$/', $k))
				$images .= '	' . $k . ': "' . $this->json_esc($v) . '",' . "\n";

		$this->padding_top = 0;
		$this->padding_right = 0;
		$this->padding_bottom = 0;
		$this->padding_left = 0;

		$str = trim($this->get('padding'));
		if ($str != '') {
			$this->padding_top = (int) $str;
			$this->padding_right = (int) $str;
			$this->padding_bottom = (int) $str;
			$this->padding_left = (int) $str;
		}

		$str = trim($this->get('padding_top'));
		if ($str != '')
			$this->padding_top = (int) $str;

		$str = trim($this->get('padding_right'));
		if ($str != '')
			$this->padding_right = (int) $str;

		$str = trim($this->get('padding_bottom'));
		if ($str != '')
			$this->padding_bottom = (int) $str;

		$str = trim($this->get('padding_left'));
		if ($str != '')
			$this->padding_left = (int) $str;

		$document->addScriptDeclaration('
document["mod_stabs_conf"].push({
'
. $this->get_int('interval')
. $this->get_int('speed')
. $this->get_str('source_id')
. $this->fmt_str('tags_tr_id', $this->tags_tr_id)
. $this->fmt_str('data_container_id', $this->data_container_id)
. $this->fmt_str('data_tr_id', $this->data_tr_id)
. $this->get_str('class_gap')
. $this->get_str('class_norm_l')
. $this->get_str('class_norm_le')
. $this->get_str('class_norm_c')
. $this->get_str('class_norm_r')
. $this->get_str('class_norm_re')
. $this->get_str('class_hover_l')
. $this->get_str('class_hover_le')
. $this->get_str('class_hover_c')
. $this->get_str('class_hover_r')
. $this->get_str('class_hover_re')
. $this->get_str('class_sel_l')
. $this->get_str('class_sel_le')
. $this->get_str('class_sel_c')
. $this->get_str('class_sel_r')
. $this->get_str('class_sel_re')
. $this->get_int('max_height')
. $this->get_int('init_selection')
. $this->get_str('tag_id_prefix')
. $this->get_bool('clear_tags_tr')
. $this->get_str('image_prefix')
. $images
. $this->fmt_int('padding_left', $this->padding_left)
. $this->fmt_int('padding_right', $this->padding_right)
. '	iname: "' . $this->json_esc($this->iname) . '"
});
');
	}
}

?>